@@ -4,7 +4,8 @@ from typing import Optional, Any
 
 import graphviz
 import networkx as nx
-from IPython.display import display
+from networkx.readwrite import json_graph
+from IPython.display import display as ipython_display
 from typeguard import typechecked
 
 import erdiagram
@@ -81,7 +82,7 @@ class ER:
         graph_attr : dict[str, Any], optional
             Graph attributes, by default dict()
         """
-        display(self.draw(engine, edge_len, graph_attr))
+        ipython_display(erdiagram.draw_er_diagram(self, engine, edge_len, graph_attr))
 
     ###############
     # Add methods #
@@ -1255,3 +1256,14 @@ class ER:
         return superclass_label in [
             self.get_entity_by_id(isA["superclass_id"])["label"] for isA in isAs
         ]
+
+    #################
+    # Other Methods #
+    #################
+
+    @typechecked
+    def as_solution(self, format="json"):
+        if format == "json":
+            return json_graph.node_link_data(self.graph)
+
+        return "please pick data format"
