@@ -15,7 +15,11 @@ def grade_submission(
     solution: erdiagram.ER,
     submission: erdiagram.ER,
     *,
-    score_missing_node: float = 1,
+    score_missing_entity: float = 1,
+    score_missing_attribute: float = 1,
+    score_missing_composed_attribute: float = 1,
+    score_missing_relation: float = 1,
+    score_missing_is_a: float = 1,
     score_missing_entity_property: float = 0.5,
     score_missing_attribute_property: float = 0.25,
     score_missing_composed_attribute_property: float = 0.125,
@@ -32,8 +36,16 @@ def grade_submission(
         The solution diagram.
     submission : erdiagram.ER
         The submission diagram.
-    score_missing_node : float, optional
-        The score to be deducted for each completely missing node, by default 1
+    score_missing_entity : float, optional
+        The score to be deducted for each missing entity, by default 1
+    score_missing_attribute : float, optional
+        The score to be deducted for each missing attribute, by default 1
+    score_missing_composed_attribute : float, optional
+        The score to be deducted for each missing composed attribute, by default 1
+    score_missing_relation : float, optional
+        The score to be deducted for each missing relation, by default 1
+    score_missing_is_a : float, optional
+        The score to be deducted for each missing is-a relation, by default 1
     score_missing_entity_property : float, optional
         The score to be deducted for each missing entity property, by default 0.5
     score_missing_attribute_property : float, optional
@@ -54,7 +66,11 @@ def grade_submission(
     """
     global scores
     scores = {
-        "missing_node": score_missing_node,
+        "missing_entity": score_missing_entity,
+        "missing_attribute": score_missing_attribute,
+        "missing_composed_attribute": score_missing_composed_attribute,
+        "missing_relation": score_missing_relation,
+        "missing_is_a": score_missing_is_a,
         "missing_entity_property": score_missing_entity_property,
         "missing_attribute_property": score_missing_attribute_property,
         "missing_composed_attribute_property": score_missing_composed_attribute_property,
@@ -187,8 +203,8 @@ def _grade_entities(
             continue
 
         # entity not found
-        log += f"\t✗ Entity '{solution_label}' not found in submission. ({scores['missing_node']})\n"
-        score += scores["missing_node"]
+        log += f"\t✗ Entity '{solution_label}' not found in submission. ({scores['missing_entity']})\n"
+        score += scores["missing_entity"]
 
     return score, log
 
@@ -372,7 +388,7 @@ def _grade_relations(
             continue
 
         # Score missing node
-        s = scores["missing_node"] * (
+        s = scores["missing_relation"] * (
             len(solution_relation["from_entities"])
             * len(solution_relation["to_entities"])
         )
@@ -435,7 +451,7 @@ def _grade_is_as(solution: erdiagram.ER, submission: erdiagram.ER) -> tuple[floa
             default=None,
         )
         if submission_is_a is None:
-            s = scores["missing_node"]
+            s = scores["missing_is_a"]
             score += s
             log += f"\t✗ Is-a relation {solution_super_label} -> {solution_sub_labels} not found in submission. ({s})\n"
             continue
@@ -572,7 +588,7 @@ def _grade_attributes(
         )
 
         if submission_attribute is None:
-            s = scores["missing_attribute_property"]
+            s = scores["missing_attribute"]
             score += s
             log += f"\t✗ Attribute {solution_attribute_label} of {str(solution_parent_type).lower()} {solution_parent_label} not found in submission.({s})\n"
             continue
@@ -605,7 +621,7 @@ def _grade_attributes(
         )
         if set_ratio < ratio_threshold:
             s = (
-                scores["missing_attribute_property"]
+                scores["missing_composed_attribute"]
                 * len(solution_attribute["composed_of_attribute_ids"])
                 * set_ratio
             )
